@@ -1,14 +1,12 @@
 use strict;
 use warnings;
 
-# vim: set ts=4 noet sw=2 textwidth=80:
-
 package Module::Data;
 BEGIN {
   $Module::Data::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Module::Data::VERSION = '0.006';
+  $Module::Data::VERSION = '0.007';
 }
 
 # ABSTRACT: Introspect context information about modules in @INC
@@ -16,135 +14,135 @@ use Moo;
 use Sub::Quote;
 
 around BUILDARGS => sub {
-	my ( $orig, $class, @args ) = @_;
+  my ( $orig, $class, @args ) = @_;
 
-	unshift @args, 'package' if @args % 2 == 1;
+  unshift @args, 'package' if @args % 2 == 1;
 
-	return $class->$orig(@args);
+  return $class->$orig(@args);
 };
 
 
 
 has package => (
-	required => 1,
-	is       => 'ro',
-	isa      => quote_sub q{}
-		. q{die "given undef for 'package' , expects a Str/module name" if not defined $_[0];}
-		. q{die " ( 'package' => $_[0] ) is not a Str/module name, got a ref : " . ref $_[0] if ref $_[0];}
-		. q{require Module::Runtime;}
-		. q{Module::Runtime::check_module_name( $_[0] );},
+  required => 1,
+  is       => 'ro',
+  isa      => quote_sub q{}
+    . q{die "given undef for 'package' , expects a Str/module name" if not defined $_[0];}
+    . q{die " ( 'package' => $_[0] ) is not a Str/module name, got a ref : " . ref $_[0] if ref $_[0];}
+    . q{require Module::Runtime;}
+    . q{Module::Runtime::check_module_name( $_[0] );},
 );
 
 has _notional_name => (
-	is      => 'ro',
-	lazy    => 1,
-	default => quote_sub q{} . q{require Module::Runtime;} . q{return Module::Runtime::module_notional_filename( $_[0]->package );},
+  is      => 'ro',
+  lazy    => 1,
+  default => quote_sub q{} . q{require Module::Runtime;} . q{return Module::Runtime::module_notional_filename( $_[0]->package );},
 );
 
 
 sub loaded {
-	my ($self) = @_;
-	return exists $INC{ $self->_notional_name };
+  my ($self) = @_;
+  return exists $INC{ $self->_notional_name };
 }
 
 
 ## no critic ( ProhibitBuiltinHomonyms )
 sub require {
-	my ($self) = @_;
-	return $self->package if $self->loaded;
+  my ($self) = @_;
+  return $self->package if $self->loaded;
 
-	require Module::Runtime;
-	Module::Runtime::require_module( $self->package );
-	return $self->package;
+  require Module::Runtime;
+  Module::Runtime::require_module( $self->package );
+  return $self->package;
 }
 
 sub _find_module_perl {
-	my ($self) = @_;
-	$self->require;
-	return $INC{ $self->_notional_name };
+  my ($self) = @_;
+  $self->require;
+  return $INC{ $self->_notional_name };
 }
 
 sub _find_module_emulate {
-	my ($self) = @_;
-	require Path::ScanINC;
-	return Path::ScanINC->new()->first_file( $self->_notional_name );
+  my ($self) = @_;
+  require Path::ScanINC;
+  return Path::ScanINC->new()->first_file( $self->_notional_name );
 }
 
 sub _find_module_optimistic {
-	my ($self) = @_;
-	return $INC{ $self->_notional_name } if $self->loaded;
-	return $self->_find_module_emulate;
+  my ($self) = @_;
+  return $INC{ $self->_notional_name } if $self->loaded;
+  return $self->_find_module_emulate;
 }
 
 ## use critic
 
 
 has path => (
-	is       => 'ro',
-	lazy     => 1,
-	init_arg => undef,
-	builder  => '_build_path',
+  is       => 'ro',
+  lazy     => 1,
+  init_arg => undef,
+  builder  => '_build_path',
 );
 
 sub _build_path {
-	require Path::Class::File;
-	return Path::Class::File->new( $_[0]->_find_module_optimistic )->absolute;
+  require Path::Class::File;
+  return Path::Class::File->new( $_[0]->_find_module_optimistic )->absolute;
 }
 
 
 has root => (
-	is       => 'ro',
-	lazy     => 1,
-	init_arg => undef,
-	builder  => '_build_root',
+  is       => 'ro',
+  lazy     => 1,
+  init_arg => undef,
+  builder  => '_build_root',
 );
 
 sub _build_root {
-	my ($path) = $_[0]->path;
+  my ($path) = $_[0]->path;
 
-	# Parent ne Self is the only cross-platform way
-	# I can think of that will stop at the top of a tree
-	# as / is not applicable on windows.
-	while ( $path->parent->absolute ne $path->absolute ) {
-		if ( not $path->is_dir ) {
-			$path = $path->parent;
-			next;
-		}
-		if ( $path->file( $_[0]->_notional_name )->absolute eq $_[0]->path->absolute ) {
-			return $path->absolute;
-		}
-		$path = $path->parent;
-	}
-	return;
+  # Parent ne Self is the only cross-platform way
+  # I can think of that will stop at the top of a tree
+  # as / is not applicable on windows.
+  while ( $path->parent->absolute ne $path->absolute ) {
+    if ( not $path->is_dir ) {
+      $path = $path->parent;
+      next;
+    }
+    if ( $path->file( $_[0]->_notional_name )->absolute eq $_[0]->path->absolute ) {
+      return $path->absolute;
+    }
+    $path = $path->parent;
+  }
+  return;
 
 }
 
 
 sub _version_perl {
-	my ($self) = @_;
-	$self->require;
+  my ($self) = @_;
+  $self->require;
 
-	# has to load the code into memory to work
-	return $self->package->VERSION;
+  # has to load the code into memory to work
+  return $self->package->VERSION;
 }
 
 sub _version_emulate {
-	my ($self) = @_;
-	my $path = $self->path;
-	require Module::Metadata;
-	my $i = Module::Metadata->new_from_file( $path, collect_pod => 0 );
-	return $i->version( $self->package );
+  my ($self) = @_;
+  my $path = $self->path;
+  require Module::Metadata;
+  my $i = Module::Metadata->new_from_file( $path, collect_pod => 0 );
+  return $i->version( $self->package );
 }
 
 sub _version_optimistic {
-	my ($self) = @_;
-	return $self->package->VERSION if $self->loaded;
-	return $self->_version_emulate;
+  my ($self) = @_;
+  return $self->package->VERSION if $self->loaded;
+  return $self->_version_emulate;
 }
 
 sub version {
-	my ( $self, @junk ) = @_;
-	return $self->_version_optimistic;
+  my ( $self, @junk ) = @_;
+  return $self->_version_optimistic;
 }
 
 
@@ -153,9 +151,10 @@ no Moo;
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -163,7 +162,7 @@ Module::Data - Introspect context information about modules in @INC
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -173,7 +172,7 @@ version 0.006
 
 	$d->path; # returns the path to where Package::Stash was found in @INC
 
-	$d->root; # returns the root directory in @INC that 'Package::Stash' was found inside. 
+	$d->root; # returns the root directory in @INC that 'Package::Stash' was found inside.
 
 	# Convenient trick to discern if you're in a development environment
 
@@ -186,9 +185,9 @@ version 0.006
 		# see File::ShareDir::ProjectDistDir for more.
 	}
 
-	# Helpful sugar. 
+	# Helpful sugar.
 
-	my $v = $d->version; 
+	my $v = $d->version;
 
 =head1 METHODS
 
@@ -198,7 +197,7 @@ Returns the package the C<Module::Data> instance was created for. ( In essence,
 this will just return the value you passed during C<new>, nothing more, nothing
 less.
 
-	my $package = $md->package 
+	my $package = $md->package
 
 =head2 loaded
 
@@ -227,14 +226,14 @@ A Path::Class::File with the absolute path to the found module.
 	my $md = Module::Data->new( 'Foo' );
 	my $path = $md->path;
 
-C<$path> is computed optimisitically. If the L</package> is listed as being
+C<$path> is computed optimistically. If the L</package> is listed as being
 L</loaded>, then it asks C<%INC> for where it was found, otherwise, the path is
-resolved by simulating C<perl>'s path lookup in C<@INC> via
+resolved by simulating C<perl>'s path look up in C<@INC> via
 L<< C<Path::ScanINC>|Path::ScanINC >>.
 
 =head2 root
 
-Returns the base directory of the tree the module was found at. 
+Returns the base directory of the tree the module was found at.
 ( Probably from @INC );
 
 	local @INC = (
@@ -255,13 +254,13 @@ If the module appears to be already loaded in memory:
 is merely shorthand for $package->VERSION;
 
 However, if if the module is not loaded into memory, all efforts to extract the
-value without loading the code permenantly are performed.
+value without loading the code permanently are performed.
 
 Here, this means we compute the path to the file manually ( see L</path> ) and
 parse the file with L<< C<Module::Metadata>|Module::Metadata >> to statically extract C<$VERSION>.
 
 This means you can unleash this code on your entire installed module tree, while
-incuring no permenant memory gain as you would normaly incur if you were to
+incurring no permanent memory gain as you would normally incur if you were to
 C<require> them all.
 
 =for Pod::Coverage   BUILDARGS
@@ -272,10 +271,9 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
